@@ -367,11 +367,15 @@ GES_START_VALIDATE_ACTION (_edit)
   REPORT_UNLESS (element, beach, "Could not find element %s", element_name);
 
   if (!_get_clocktime (action->structure, "position", &position, &fposition)) {
-    fposition = 0;
-    if (!gst_structure_get_int (action->structure, "source-frame",
-            (gint *) & fposition)
-        && !gst_structure_get_int64 (action->structure, "source-frame",
-            &fposition)) {
+    gint pos;
+    gint64 pos64;
+
+    if (gst_structure_get_int (action->structure, "source-frame", &pos)) {
+      fposition = pos;
+    } else if (gst_structure_get_int64 (action->structure, "source-frame",
+            &pos64)) {
+      fposition = pos64;
+    } else {
       gchar *structstr = gst_structure_to_string (action->structure);
 
       GST_VALIDATE_REPORT_ACTION (scenario, action,
@@ -530,11 +534,12 @@ typedef struct
 } PropertyData;
 
 static gboolean
-check_property (GQuark field_id, GValue * expected_value, PropertyData * data)
+check_property (const GstIdStr * fieldname, GValue * expected_value,
+    PropertyData * data)
 {
   GValue cvalue = G_VALUE_INIT, *tvalue = NULL, comparable_value = G_VALUE_INIT,
       *observed_value;
-  const gchar *property = g_quark_to_string (field_id);
+  const gchar *property = gst_id_str_as_str (fieldname);
   GstControlBinding *binding = NULL;
 
   if (!data->on_children) {
@@ -661,9 +666,10 @@ compare:
 }
 
 static gboolean
-set_property (GQuark field_id, const GValue * value, PropertyData * data)
+set_property (const GstIdStr * fieldname, const GValue * value,
+    PropertyData * data)
 {
-  const gchar *property = g_quark_to_string (field_id);
+  const gchar *property = gst_id_str_as_str (fieldname);
 
   if (data->on_children) {
     if (!ges_timeline_element_set_child_property (data->element, property,
@@ -725,9 +731,9 @@ GES_START_VALIDATE_ACTION (set_or_check_properties)
   data.element = element;
   gst_structure_remove_fields (structure, "element-name", "at-time",
       "project-uri", NULL);
-  gst_structure_foreach (structure,
-      is_setting ? (GstStructureForeachFunc) set_property
-      : (GstStructureForeachFunc) check_property, &data);
+  gst_structure_foreach_id_str (structure,
+      is_setting ? (GstStructureForeachIdStrFunc) set_property
+      : (GstStructureForeachIdStrFunc) check_property, &data);
   gst_object_unref (element);
 
 local_done:
@@ -829,6 +835,48 @@ beach:
 
 GST_END_VALIDATE_ACTION;
 
+GES_START_VALIDATE_ACTION (_group)
+{
+  gint i;
+  GESContainer *group;
+  GList *containers = NULL;
+  gchar **container_names;
+  const gchar *container_name =
+      gst_structure_get_string (action->structure, "container-name");
+
+  REPORT_UNLESS ((container_names =
+          gst_validate_utils_get_strv (action->structure, "containers")), beach,
+      "Could not get container names from structure %" GST_PTR_FORMAT,
+      action->structure);
+
+  for (i = 0; container_names[i]; i++) {
+    GESContainer *container =
+        (GESContainer *) ges_timeline_get_element (timeline,
+        container_names[i]);
+
+    REPORT_UNLESS (GES_IS_CONTAINER (container), beach, "Could not find %s",
+        container_names[i]);
+
+    containers = g_list_prepend (containers, container);
+  }
+
+  REPORT_UNLESS ((group = ges_container_group (containers)), beach,
+      "Grouping failed");
+
+  if (container_name) {
+    REPORT_UNLESS (ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (group),
+            container_name), beach, "Could not set element name %s",
+        container_name);
+
+  }
+
+beach:
+  g_clear_pointer (&container_names, g_strfreev);
+  g_list_free_full (containers, gst_object_unref);
+}
+
+GST_END_VALIDATE_ACTION;
+
 GES_START_VALIDATE_ACTION (_ungroup)
 {
   GESContainer *container;
@@ -1673,6 +1721,29 @@ ges_validate_register_action_types (void)
         {NULL}
       }, "Remove a child from @container-name.", FALSE);
 
+  gst_validate_register_action_type ("group", "ges", _group,
+      (GstValidateActionParameter []) {
+        {
+          .name = "container-name",
+          .description = "The name of the resulting group",
+          .types = "string",
+          .mandatory = FALSE,
+        },
+        {
+          .name = "containers",
+          .description = "Array of GESContainer names to group",
+          .types = "{ container-name, }",
+          .mandatory = TRUE,
+        },
+        {
+          .name = "project-uri",
+          .description = "The project URI with the serialized timeline to execute the action on",
+          .types = "string",
+          .mandatory = FALSE,
+        },
+        {NULL}
+      }, "Group containers together.", FALSE);
+
   gst_validate_register_action_type ("ungroup-container", "ges", _ungroup,
       (GstValidateActionParameter []) {
         {
